SWF — boto v2.21.1

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »

# SWF

## boto.swf

`boto.swf.` `connect_to_region`(region_name, **kw_params)

`boto.swf.` `regions`(**kw_params)

  Get all available regions for the Amazon Simple Workflow service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.swf.layer1

class `boto.swf.layer1.` `Layer1`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, debug=0, session_token=None, region=None)

  Low-level interface to Simple WorkFlow Service.

  `DefaultRegionName` = 'us-east-1'

    The default region name for Simple Workflow.

  `ResponseError`

    alias of `SWFResponseError`

  `ServiceName` = 'com.amazonaws.swf.service.model.SimpleWorkflowService'

    The name of the Service

  `count_closed_workflow_executions`(domain, start_latest_date=None, start_oldest_date=None, close_latest_date=None, close_oldest_date=None, close_status=None, tag=None, workflow_id=None, workflow_name=None, workflow_version=None)

    Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria.

    Parameters: | domain (string) – The name of the domain containing the workflow executions to count. start_latest_date (timestamp) – If specified, only workflow executions that meet the start time criteria of the filter are counted. start_oldest_date (timestamp) – If specified, only workflow executions that meet the start time criteria of the filter are counted. close_latest_date (timestamp) – If specified, only workflow executions that meet the close time criteria of the filter are counted. close_oldest_date (timestamp) – If specified, only workflow executions that meet the close time criteria of the filter are counted. close_status (string) – The close status that must match the close status of an execution for it to meet the criteria of this filter. Valid values are: COMPLETED FAILED CANCELED TERMINATED CONTINUED_AS_NEW TIMED_OUT tag (string) – If specified, only executions that have a tag that matches the filter are counted. workflow_id (string) – If specified, only workflow executions matching the workflow_id are counted. workflow_name (string) – Name of the workflow type to filter on. workflow_version (string) – Version of the workflow type to filter on.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `count_open_workflow_executions`(domain, latest_date, oldest_date, tag=None, workflow_id=None, workflow_name=None, workflow_version=None)

    Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.

    Parameters: | domain (string) – The name of the domain containing the workflow executions to count. latest_date (timestamp) – Specifies the latest start or close date and time to return. oldest_date (timestamp) – Specifies the oldest start or close date and time to return. workflow_name (string) – Name of the workflow type to filter on. workflow_version (string) – Version of the workflow type to filter on. tag (string) – If specified, only executions that have a tag that matches the filter are counted. workflow_id (string) – If specified, only workflow executions matching the workflow_id are counted.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `count_pending_activity_tasks`(domain, task_list)

    Returns the estimated number of activity tasks in the specified task list. The count returned is an approximation and is not guaranteed to be exact. If you specify a task list that no activity task was ever scheduled in then 0 will be returned.

    Parameters: | domain (string) – The name of the domain that contains the task list. task_list (string) – The name of the task list.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `count_pending_decision_tasks`(domain, task_list)

    Returns the estimated number of decision tasks in the specified task list. The count returned is an approximation and is not guaranteed to be exact. If you specify a task list that no decision task was ever scheduled in then 0 will be returned.

    Parameters: | domain (string) – The name of the domain that contains the task list. task_list (string) – The name of the task list.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `deprecate_activity_type`(domain, activity_name, activity_version)

    Returns information about the specified activity type. This includes configuration settings provided at registration time as well as other general information about the type.

    Parameters: | domain (string) – The name of the domain in which the activity type is registered. activity_name (string) – The name of this activity. activity_version (string) – The version of this activity.
    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFOperationNotPermittedError

  `deprecate_domain`(name)

    Deprecates the specified domain. After a domain has been deprecated it cannot be used to create new workflow executions or register new types. However, you can still use visibility actions on this domain. Deprecating a domain also deprecates all activity and workflow types registered in the domain. Executions that were started before the domain was deprecated will continue to run.

    Parameters: | name (string) – The name of the domain to deprecate.
    Raises : | UnknownResourceFault, DomainDeprecatedFault, SWFOperationNotPermittedError

  `deprecate_workflow_type`(domain, workflow_name, workflow_version)

    Deprecates the specified workflow type. After a workflow type has been deprecated, you cannot create new executions of that type. Executions that were started before the type was deprecated will continue to run. A deprecated workflow type may still be used when calling visibility actions.

    Parameters: | domain (string) – The name of the domain in which the workflow type is registered. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type.
    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFOperationNotPermittedError

  `describe_activity_type`(domain, activity_name, activity_version)

    Returns information about the specified activity type. This includes configuration settings provided at registration time as well as other general information about the type.

    Parameters: | domain (string) – The name of the domain in which the activity type is registered. activity_name (string) – The name of this activity. activity_version (string) – The version of this activity.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `describe_domain`(name)

    Returns information about the specified domain including description and status.

    Parameters: | name (string) – The name of the domain to describe.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `describe_workflow_execution`(domain, run_id, workflow_id)

    Returns information about the specified workflow execution including its type and some statistics.

    Parameters: | domain (string) – The name of the domain containing the workflow execution. run_id (string) – A system generated unique identifier for the workflow execution. workflow_id (string) – The user defined identifier associated with the workflow execution.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `describe_workflow_type`(domain, workflow_name, workflow_version)

    Returns information about the specified workflow type. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.

    Parameters: | domain (string) – The name of the domain in which this workflow type is registered. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `get_workflow_execution_history`(domain, run_id, workflow_id, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Returns the history of the specified workflow execution. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.

    Parameters: | domain (string) – The name of the domain containing the workflow execution. run_id (string) – A system generated unique identifier for the workflow execution. workflow_id (string) – The user defined identifier associated with the workflow execution. maximum_page_size (integer) – Specifies the maximum number of history events returned in one page. The next page in the result is identified by the NextPageToken returned. By default 100 history events are returned in a page but the caller can override this value to a page size smaller than the default. You cannot specify a page size larger than 100. next_page_token (string) – If a NextPageToken is returned, the result has more than one pages. To get the next page, repeat the call and specify the nextPageToken with all other arguments unchanged. reverse_order (boolean) – When set to true, returns the events in reverse order. By default the results are returned in ascending order of the eventTimeStamp of the events.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `json_request`(action, data, object_hook=None)

    This method wraps around make_request() to normalize and serialize the dictionary with request parameters.

    Parameters: | action (string) – Specifies an SWF action. data (dict) – Specifies request parameters associated with the action.

  `list_activity_types`(domain, registration_status, name=None, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Returns information about all activities registered in the specified domain that match the specified name and registration status. The result includes information like creation date, current status of the activity, etc. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.

    Parameters: | domain (string) – The name of the domain in which the activity types have been registered. registration_status (string) – Specifies the registration status of the activity types to list. Valid values are: REGISTERED DEPRECATED name (string) – If specified, only lists the activity types that have this name. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextResultToken was returned, the results have more than one page. To get the next page of results, repeat the call with the nextPageToken and keep all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the activity types.
    Raises : | SWFOperationNotPermittedError, UnknownResourceFault

  `list_closed_workflow_executions`(domain, start_latest_date=None, start_oldest_date=None, close_latest_date=None, close_oldest_date=None, close_status=None, tag=None, workflow_id=None, workflow_name=None, workflow_version=None, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria.

    Parameters: | domain (string) – The name of the domain containing the workflow executions to count. start_latest_date (timestamp) – If specified, only workflow executions that meet the start time criteria of the filter are counted. start_oldest_date (timestamp) – If specified, only workflow executions that meet the start time criteria of the filter are counted. close_latest_date (timestamp) – If specified, only workflow executions that meet the close time criteria of the filter are counted. close_oldest_date (timestamp) – If specified, only workflow executions that meet the close time criteria of the filter are counted. close_status (string) – The close status that must match the close status of an execution for it to meet the criteria of this filter. Valid values are: COMPLETED FAILED CANCELED TERMINATED CONTINUED_AS_NEW TIMED_OUT tag (string) – If specified, only executions that have a tag that matches the filter are counted. workflow_id (string) – If specified, only workflow executions matching the workflow_id are counted. workflow_name (string) – Name of the workflow type to filter on. workflow_version (string) – Version of the workflow type to filter on. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in descending order of the start or the close time of the executions.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `list_domains`(registration_status, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Returns the list of domains registered in the account. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.

    Parameters: | registration_status (string) – Specifies the registration status of the domains to list. Valid Values: REGISTERED DEPRECATED maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the result has more than one page. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the domains.
    Raises : | SWFOperationNotPermittedError

  `list_open_workflow_executions`(domain, oldest_date, latest_date=None, tag=None, workflow_id=None, workflow_name=None, workflow_version=None, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Returns the list of open workflow executions within the given domain that meet the specified filtering criteria.

    Parameters: | domain (string) – The name of the domain containing the workflow executions to count. latest_date (timestamp) – Specifies the latest start or close date and time to return. oldest_date (timestamp) – Specifies the oldest start or close date and time to return. tag (string) – If specified, only executions that have a tag that matches the filter are counted. workflow_id (string) – If specified, only workflow executions matching the workflow_id are counted. workflow_name (string) – Name of the workflow type to filter on. workflow_version (string) – Version of the workflow type to filter on. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in descending order of the start or the close time of the executions.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `list_workflow_types`(domain, registration_status, maximum_page_size=None, name=None, next_page_token=None, reverse_order=None)

    Returns information about workflow types in the specified domain. The results may be split into multiple pages that can be retrieved by making the call repeatedly.

    Parameters: | domain (string) – The name of the domain in which the workflow types have been registered. registration_status (string) – Specifies the registration status of the activity types to list. Valid values are: REGISTERED DEPRECATED name (string) – If specified, lists the workflow type with this name. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the workflow types.
    Raises : | SWFOperationNotPermittedError, UnknownResourceFault

  `make_request`(action, body='', object_hook=None)

    Raises : | `SWFResponseError` if response status is not 200.

  `poll_for_activity_task`(domain, task_list, identity=None)

    Used by workers to get an ActivityTask from the specified activity taskList. This initiates a long poll, where the service holds the HTTP connection open and responds as soon as a task becomes available. The maximum time the service holds on to the request before responding is 60 seconds. If no task is available within 60 seconds, the poll will return an empty result. An empty result, in this context, means that an ActivityTask is returned, but that the value of taskToken is an empty string. If a task is returned, the worker should use its type to identify and process it correctly.

    Parameters: | domain (string) – The name of the domain that contains the task lists being polled. task_list (string) – Specifies the task list to poll for activity tasks. identity (string) – Identity of the worker making the request, which is recorded in the ActivityTaskStarted event in the workflow history. This enables diagnostic tracing when problems arise. The form of this identity is user defined.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `poll_for_decision_task`(domain, task_list, identity=None, maximum_page_size=None, next_page_token=None, reverse_order=None)

    Used by deciders to get a DecisionTask from the specified decision taskList. A decision task may be returned for any open workflow execution that is using the specified task list. The task includes a paginated view of the history of the workflow execution. The decider should use the workflow type and the history to determine how to properly handle the task.

    Parameters: | domain (string) – The name of the domain containing the task lists to poll. task_list (string) – Specifies the task list to poll for decision tasks. identity (string) – Identity of the decider making the request, which is recorded in the DecisionTaskStarted event in the workflow history. This enables diagnostic tracing when problems arise. The form of this identity is user defined. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the events in reverse order. By default the results are returned in ascending order of the eventTimestamp of the events.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `record_activity_task_heartbeat`(task_token, details=None)

    Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress. The worker can also (optionally) specify details of the progress, for example percent complete, using the details parameter. This action can also be used by the worker as a mechanism to check if cancellation is being requested for the activity task. If a cancellation is being attempted for the specified task, then the boolean cancelRequested flag returned by the service is set to true.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – If specified, contains details about the progress of the task.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `register_activity_type`(domain, name, version, task_list=None, default_task_heartbeat_timeout=None, default_task_schedule_to_close_timeout=None, default_task_schedule_to_start_timeout=None, default_task_start_to_close_timeout=None, description=None)

    Registers a new activity type along with its configuration settings in the specified domain.

    Parameters: | domain (string) – The name of the domain in which this activity is to be registered. name (string) – The name of the activity type within the domain. version (string) – The version of the activity type. task_list (string) – If set, specifies the default task list to use for scheduling tasks of this activity type. This default task list is used if a task list is not provided when a task is scheduled through the schedule_activity_task Decision. default_task_heartbeat_timeout (string) – If set, specifies the default maximum time before which a worker processing a task of this type must report progress by calling RecordActivityTaskHeartbeat. If the timeout is exceeded, the activity task is automatically timed out. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. If the activity worker subsequently attempts to record a heartbeat or returns a result, the activity worker receives an UnknownResource fault. In this case, Amazon SWF no longer considers the activity task to be valid; the activity worker should clean up the activity task.no docs default_task_schedule_to_close_timeout (string) – If set, specifies the default maximum duration for a task of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision.no docs default_task_schedule_to_start_timeout (string) – If set, specifies the default maximum duration that a task of this activity type can wait before being assigned to a worker. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. default_task_start_to_close_timeout (string) – If set, specifies the default maximum duration that a worker can take to process tasks of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. description (string) – A textual description of the activity type.
    Raises : | SWFTypeAlreadyExistsError, SWFLimitExceededError, UnknownResourceFault, SWFOperationNotPermittedError

  `register_domain`(name, workflow_execution_retention_period_in_days, description=None)

    Registers a new domain.

    Parameters: | name (string) – Name of the domain to register. The name must be unique. workflow_execution_retention_period_in_days (string) – Specifies the duration in days for which the record (including the history) of workflow executions in this domain should be kept by the service. After the retention period, the workflow execution will not be available in the results of visibility calls. If a duration of NONE is specified, the records for workflow executions in this domain are not retained at all. description (string) – Textual description of the domain.
    Raises : | SWFDomainAlreadyExistsError, SWFLimitExceededError, SWFOperationNotPermittedError

  `register_workflow_type`(domain, name, version, task_list=None, default_child_policy=None, default_execution_start_to_close_timeout=None, default_task_start_to_close_timeout=None, description=None)

    Registers a new workflow type and its configuration settings in the specified domain.

    Parameters: | domain (string) – The name of the domain in which to register the workflow type. name (string) – The name of the workflow type. version (string) – The version of the workflow type. task_list (list of name, version of tasks) – If set, specifies the default task list to use for scheduling decision tasks for executions of this workflow type. This default is used only if a task list is not provided when starting the execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. default_child_policy (string) – If set, specifies the default policy to use for the child workflow executions when a workflow execution of this type is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run.no docs default_execution_start_to_close_timeout (string) – If set, specifies the default maximum duration for executions of this workflow type. You can override this default when starting an execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. default_task_start_to_close_timeout (string) – If set, specifies the default maximum duration of decision tasks for this workflow type. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. description (string) – Textual description of the workflow type.
    Raises : | SWFTypeAlreadyExistsError, SWFLimitExceededError, UnknownResourceFault, SWFOperationNotPermittedError

  `request_cancel_workflow_execution`(domain, workflow_id, run_id=None)

    Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId. This logically requests the cancellation of the workflow execution as a whole. It is up to the decider to take appropriate actions when it receives an execution history with this event.

    Parameters: | domain (string) – The name of the domain containing the workflow execution to cancel. run_id (string) – The runId of the workflow execution to cancel. workflow_id (string) – The workflowId of the workflow execution to cancel.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `respond_activity_task_canceled`(task_token, details=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled. Additional details can be optionally provided using the details argument.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – Optional detailed information about the failure.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `respond_activity_task_completed`(task_token, result=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided).

    Parameters: | task_token (string) – The taskToken of the ActivityTask. result (string) – The result of the activity task. It is a free form string that is implementation specific.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `respond_activity_task_failed`(task_token, details=None, reason=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified).

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – Optional detailed information about the failure. reason (string) – Description of the error that may assist in diagnostics.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `respond_decision_task_completed`(task_token, decisions=None, execution_context=None)

    Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. decisions (list) – The list of decisions (possibly empty) made by the decider while processing this decision task. See the docs for the Decision structure for details. execution_context (string) – User defined context to add to workflow execution.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `signal_workflow_execution`(domain, signal_name, workflow_id, input=None, run_id=None)

    Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId. The event is recorded with the specified user defined signalName and input (if provided).

    Parameters: | domain (string) – The name of the domain containing the workflow execution to signal. signal_name (string) – The name of the signal. This name must be meaningful to the target workflow. workflow_id (string) – The workflowId of the workflow execution to signal. input (string) – Data to attach to the WorkflowExecutionSignaled event in the target workflow execution’s history. run_id (string) – The runId of the workflow execution to signal.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `start_workflow_execution`(domain, workflow_id, workflow_name, workflow_version, task_list=None, child_policy=None, execution_start_to_close_timeout=None, input=None, tag_list=None, task_start_to_close_timeout=None)

    Starts an execution of the workflow type in the specified domain using the provided workflowId and input data.

    Parameters: | domain (string) – The name of the domain in which the workflow execution is created. workflow_id (string) – The user defined identifier associated with the workflow execution. You can use this to associate a custom identifier with the workflow execution. You may specify the same identifier if a workflow execution is logically a restart of a previous execution. You cannot have two open workflow executions with the same workflowId at the same time. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type. task_list (string) – The task list to use for the decision tasks generated for this workflow execution. This overrides the defaultTaskList specified when registering the workflow type. child_policy (string) – If set, specifies the policy to use for the child workflow executions of this workflow execution if it is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This policy overrides the default child policy specified when registering the workflow type using RegisterWorkflowType. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run. execution_start_to_close_timeout (string) – The total duration for this workflow execution. This overrides the defaultExecutionStartToCloseTimeout specified when registering the workflow type. input (string) – The input for the workflow execution. This is a free form string which should be meaningful to the workflow you are starting. This input is made available to the new workflow execution in the WorkflowExecutionStarted history event.

    task_start_to_close_timeout: Specifies the maximum duration of
      decision tasks for this workflow execution. This parameter overrides the defaultTaskStartToCloseTimout specified when registering the workflow type using register_workflow_type.

    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFWorkflowExecutionAlreadyStartedError, SWFLimitExceededError, SWFOperationNotPermittedError, DefaultUndefinedFault

  `terminate_workflow_execution`(domain, workflow_id, child_policy=None, details=None, reason=None, run_id=None)

    Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId. The child policy, registered with the workflow type or specified when starting this execution, is applied to any open child workflow executions of this workflow execution.

    Parameters: | domain (string) – The domain of the workflow execution to terminate. workflow_id (string) – The workflowId of the workflow execution to terminate. child_policy (string) – If set, specifies the policy to use for the child workflow executions of the workflow execution being terminated. This policy overrides the child policy specified for the workflow execution at registration time or when starting the execution. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run. details (string) – Optional details for terminating the workflow execution. reason (string) – An optional descriptive reason for terminating the workflow execution. run_id (string) – The runId of the workflow execution to terminate.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

## boto.swf.layer2

Object-oriented interface to SWF wrapping boto.swf.layer1.Layer1

class `boto.swf.layer2.` `ActivityType`(**kwargs)

  A versioned activity type.

  `deprecate`()

    Returns information about the specified activity type. This includes configuration settings provided at registration time as well as other general information about the type.

    Parameters: | domain (string) – The name of the domain in which the activity type is registered. activity_name (string) – The name of this activity. activity_version (string) – The version of this activity.
    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFOperationNotPermittedError

  `describe`()

    Returns information about the specified activity type. This includes configuration settings provided at registration time as well as other general information about the type.

    Parameters: | domain (string) – The name of the domain in which the activity type is registered. activity_name (string) – The name of this activity. activity_version (string) – The version of this activity.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `register`(**kwargs)

    Registers a new activity type along with its configuration settings in the specified domain.

    Parameters: | domain (string) – The name of the domain in which this activity is to be registered. name (string) – The name of the activity type within the domain. version (string) – The version of the activity type. task_list (string) – If set, specifies the default task list to use for scheduling tasks of this activity type. This default task list is used if a task list is not provided when a task is scheduled through the schedule_activity_task Decision. default_task_heartbeat_timeout (string) – If set, specifies the default maximum time before which a worker processing a task of this type must report progress by calling RecordActivityTaskHeartbeat. If the timeout is exceeded, the activity task is automatically timed out. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. If the activity worker subsequently attempts to record a heartbeat or returns a result, the activity worker receives an UnknownResource fault. In this case, Amazon SWF no longer considers the activity task to be valid; the activity worker should clean up the activity task.no docs default_task_schedule_to_close_timeout (string) – If set, specifies the default maximum duration for a task of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision.no docs default_task_schedule_to_start_timeout (string) – If set, specifies the default maximum duration that a task of this activity type can wait before being assigned to a worker. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. default_task_start_to_close_timeout (string) – If set, specifies the default maximum duration that a worker can take to process tasks of this activity type. This default can be overridden when scheduling an activity task using the ScheduleActivityTask Decision. description (string) – A textual description of the activity type.
    Raises : | SWFTypeAlreadyExistsError, SWFLimitExceededError, UnknownResourceFault, SWFOperationNotPermittedError

class `boto.swf.layer2.` `ActivityWorker`(**kwargs)

  Base class for SimpleWorkflow activity workers.

  `cancel`(task_token=None, details=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled. Additional details can be optionally provided using the details argument.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – Optional detailed information about the failure.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `complete`(task_token=None, result=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided).

    Parameters: | task_token (string) – The taskToken of the ActivityTask. result (string) – The result of the activity task. It is a free form string that is implementation specific.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `fail`(task_token=None, details=None, reason=None)

    Used by workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified).

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – Optional detailed information about the failure. reason (string) – Description of the error that may assist in diagnostics.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `heartbeat`(task_token=None, details=None)

    Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress. The worker can also (optionally) specify details of the progress, for example percent complete, using the details parameter. This action can also be used by the worker as a mechanism to check if cancellation is being requested for the activity task. If a cancellation is being attempted for the specified task, then the boolean cancelRequested flag returned by the service is set to true.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. details (string) – If specified, contains details about the progress of the task.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `poll`(**kwargs)

    Used by workers to get an ActivityTask from the specified activity taskList. This initiates a long poll, where the service holds the HTTP connection open and responds as soon as a task becomes available. The maximum time the service holds on to the request before responding is 60 seconds. If no task is available within 60 seconds, the poll will return an empty result. An empty result, in this context, means that an ActivityTask is returned, but that the value of taskToken is an empty string. If a task is returned, the worker should use its type to identify and process it correctly.

    Parameters: | domain (string) – The name of the domain that contains the task lists being polled. task_list (string) – Specifies the task list to poll for activity tasks. identity (string) – Identity of the worker making the request, which is recorded in the ActivityTaskStarted event in the workflow history. This enables diagnostic tracing when problems arise. The form of this identity is user defined.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

class `boto.swf.layer2.` `Decider`(**kwargs)

  Base class for SimpleWorkflow deciders.

  `complete`(task_token=None, decisions=None, **kwargs)

    Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed. The decisions argument specifies the list of decisions made while processing the task.

    Parameters: | task_token (string) – The taskToken of the ActivityTask. decisions (list) – The list of decisions (possibly empty) made by the decider while processing this decision task. See the docs for the Decision structure for details. execution_context (string) – User defined context to add to workflow execution.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `poll`(**kwargs)

    Used by deciders to get a DecisionTask from the specified decision taskList. A decision task may be returned for any open workflow execution that is using the specified task list. The task includes a paginated view of the history of the workflow execution. The decider should use the workflow type and the history to determine how to properly handle the task.

    Parameters: | domain (string) – The name of the domain containing the task lists to poll. task_list (string) – Specifies the task list to poll for decision tasks. identity (string) – Identity of the decider making the request, which is recorded in the DecisionTaskStarted event in the workflow history. This enables diagnostic tracing when problems arise. The form of this identity is user defined. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the events in reverse order. By default the results are returned in ascending order of the eventTimestamp of the events.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

class `boto.swf.layer2.` `Domain`(**kwargs)

  Simple Workflow Domain.

  `activities`(status='REGISTERED', **kwargs)

    Returns information about all activities registered in the specified domain that match the specified name and registration status. The result includes information like creation date, current status of the activity, etc. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.

    Parameters: | domain (string) – The name of the domain in which the activity types have been registered. registration_status (string) – Specifies the registration status of the activity types to list. Valid values are: REGISTERED DEPRECATED name (string) – If specified, only lists the activity types that have this name. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextResultToken was returned, the results have more than one page. To get the next page of results, repeat the call with the nextPageToken and keep all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the activity types.
    Raises : | SWFOperationNotPermittedError, UnknownResourceFault

  `count_pending_activity_tasks`(task_list)

    Returns the estimated number of activity tasks in the specified task list. The count returned is an approximation and is not guaranteed to be exact. If you specify a task list that no activity task was ever scheduled in then 0 will be returned.

    Parameters: | domain (string) – The name of the domain that contains the task list. task_list (string) – The name of the task list.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `count_pending_decision_tasks`(task_list)

    Returns the estimated number of decision tasks in the specified task list. The count returned is an approximation and is not guaranteed to be exact. If you specify a task list that no decision task was ever scheduled in then 0 will be returned.

    Parameters: | domain (string) – The name of the domain that contains the task list. task_list (string) – The name of the task list.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `deprecate`()

    Deprecates the specified domain. After a domain has been deprecated it cannot be used to create new workflow executions or register new types. However, you can still use visibility actions on this domain. Deprecating a domain also deprecates all activity and workflow types registered in the domain. Executions that were started before the domain was deprecated will continue to run.

    Parameters: | name (string) – The name of the domain to deprecate.
    Raises : | UnknownResourceFault, DomainDeprecatedFault, SWFOperationNotPermittedError

  `describe`()

    Returns information about the specified domain including description and status.

    Parameters: | name (string) – The name of the domain to describe.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `executions`(closed=False, **kwargs)

    List list open/closed executions.

    For a full list of available parameters refer to `boto.swf.layer1.Layer1.list_closed_workflow_executions()` and `boto.swf.layer1.Layer1.list_open_workflow_executions()`

  `register`()

    Registers a new domain.

    Parameters: | name (string) – Name of the domain to register. The name must be unique. workflow_execution_retention_period_in_days (string) – Specifies the duration in days for which the record (including the history) of workflow executions in this domain should be kept by the service. After the retention period, the workflow execution will not be available in the results of visibility calls. If a duration of NONE is specified, the records for workflow executions in this domain are not retained at all. description (string) – Textual description of the domain.
    Raises : | SWFDomainAlreadyExistsError, SWFLimitExceededError, SWFOperationNotPermittedError

  `workflows`(status='REGISTERED', **kwargs)

    Returns information about workflow types in the specified domain. The results may be split into multiple pages that can be retrieved by making the call repeatedly.

    Parameters: | domain (string) – The name of the domain in which the workflow types have been registered. registration_status (string) – Specifies the registration status of the activity types to list. Valid values are: REGISTERED DEPRECATED name (string) – If specified, lists the workflow type with this name. maximum_page_size (integer) – The maximum number of results returned in each page. The default is 100, but the caller can override this value to a page size smaller than the default. You cannot specify a page size greater than 100. next_page_token (string) – If on a previous call to this method a NextPageToken was returned, the results are being paginated. To get the next page of results, repeat the call with the returned token and all other arguments unchanged. reverse_order (boolean) – When set to true, returns the results in reverse order. By default the results are returned in ascending alphabetical order of the name of the workflow types.
    Raises : | SWFOperationNotPermittedError, UnknownResourceFault

class `boto.swf.layer2.` `WorkflowExecution`(**kwargs)

  An instance of a workflow.

  `describe`()

    Returns information about the specified workflow execution including its type and some statistics.

    Parameters: | domain (string) – The name of the domain containing the workflow execution. run_id (string) – A system generated unique identifier for the workflow execution. workflow_id (string) – The user defined identifier associated with the workflow execution.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `history`(**kwargs)

    Returns the history of the specified workflow execution. The results may be split into multiple pages. To retrieve subsequent pages, make the call again using the nextPageToken returned by the initial call.

    Parameters: | domain (string) – The name of the domain containing the workflow execution. run_id (string) – A system generated unique identifier for the workflow execution. workflow_id (string) – The user defined identifier associated with the workflow execution. maximum_page_size (integer) – Specifies the maximum number of history events returned in one page. The next page in the result is identified by the NextPageToken returned. By default 100 history events are returned in a page but the caller can override this value to a page size smaller than the default. You cannot specify a page size larger than 100. next_page_token (string) – If a NextPageToken is returned, the result has more than one pages. To get the next page, repeat the call and specify the nextPageToken with all other arguments unchanged. reverse_order (boolean) – When set to true, returns the events in reverse order. By default the results are returned in ascending order of the eventTimeStamp of the events.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `request_cancel`()

    Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId. This logically requests the cancellation of the workflow execution as a whole. It is up to the decider to take appropriate actions when it receives an execution history with this event.

    Parameters: | domain (string) – The name of the domain containing the workflow execution to cancel. run_id (string) – The runId of the workflow execution to cancel. workflow_id (string) – The workflowId of the workflow execution to cancel.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `signal`(signame, **kwargs)

    Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId. The event is recorded with the specified user defined signalName and input (if provided).

    Parameters: | domain (string) – The name of the domain containing the workflow execution to signal. signal_name (string) – The name of the signal. This name must be meaningful to the target workflow. workflow_id (string) – The workflowId of the workflow execution to signal. input (string) – Data to attach to the WorkflowExecutionSignaled event in the target workflow execution’s history. run_id (string) – The runId of the workflow execution to signal.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `terminate`(**kwargs)

    Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId. The child policy, registered with the workflow type or specified when starting this execution, is applied to any open child workflow executions of this workflow execution.

    Parameters: | domain (string) – The domain of the workflow execution to terminate. workflow_id (string) – The workflowId of the workflow execution to terminate. child_policy (string) – If set, specifies the policy to use for the child workflow executions of the workflow execution being terminated. This policy overrides the child policy specified for the workflow execution at registration time or when starting the execution. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run. details (string) – Optional details for terminating the workflow execution. reason (string) – An optional descriptive reason for terminating the workflow execution. run_id (string) – The runId of the workflow execution to terminate.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

class `boto.swf.layer2.` `WorkflowType`(**kwargs)

  A versioned workflow type.

  `deprecate`()

    Deprecates the specified workflow type. After a workflow type has been deprecated, you cannot create new executions of that type. Executions that were started before the type was deprecated will continue to run. A deprecated workflow type may still be used when calling visibility actions.

    Parameters: | domain (string) – The name of the domain in which the workflow type is registered. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type.
    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFOperationNotPermittedError

  `describe`()

    Returns information about the specified workflow type. This includes configuration settings specified when the type was registered and other information such as creation date, current status, etc.

    Parameters: | domain (string) – The name of the domain in which this workflow type is registered. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type.
    Raises : | UnknownResourceFault, SWFOperationNotPermittedError

  `register`(**kwargs)

    Registers a new workflow type and its configuration settings in the specified domain.

    Parameters: | domain (string) – The name of the domain in which to register the workflow type. name (string) – The name of the workflow type. version (string) – The version of the workflow type. task_list (list of name, version of tasks) – If set, specifies the default task list to use for scheduling decision tasks for executions of this workflow type. This default is used only if a task list is not provided when starting the execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. default_child_policy (string) – If set, specifies the default policy to use for the child workflow executions when a workflow execution of this type is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run.no docs default_execution_start_to_close_timeout (string) – If set, specifies the default maximum duration for executions of this workflow type. You can override this default when starting an execution through the StartWorkflowExecution Action or StartChildWorkflowExecution Decision. default_task_start_to_close_timeout (string) – If set, specifies the default maximum duration of decision tasks for this workflow type. This default can be overridden when starting a workflow execution using the StartWorkflowExecution action or the StartChildWorkflowExecution Decision. description (string) – Textual description of the workflow type.
    Raises : | SWFTypeAlreadyExistsError, SWFLimitExceededError, UnknownResourceFault, SWFOperationNotPermittedError

  `start`(**kwargs)

    Starts an execution of the workflow type in the specified domain using the provided workflowId and input data.

    Parameters: | domain (string) – The name of the domain in which the workflow execution is created. workflow_id (string) – The user defined identifier associated with the workflow execution. You can use this to associate a custom identifier with the workflow execution. You may specify the same identifier if a workflow execution is logically a restart of a previous execution. You cannot have two open workflow executions with the same workflowId at the same time. workflow_name (string) – The name of the workflow type. workflow_version (string) – The version of the workflow type. task_list (string) – The task list to use for the decision tasks generated for this workflow execution. This overrides the defaultTaskList specified when registering the workflow type. child_policy (string) – If set, specifies the policy to use for the child workflow executions of this workflow execution if it is terminated, by calling the TerminateWorkflowExecution action explicitly or due to an expired timeout. This policy overrides the default child policy specified when registering the workflow type using RegisterWorkflowType. The supported child policies are: TERMINATE: the child executions will be terminated. REQUEST_CANCEL: a request to cancel will be attempted for each child execution by recording a WorkflowExecutionCancelRequested event in its history. It is up to the decider to take appropriate actions when it receives an execution history with this event. ABANDON: no action will be taken. The child executions will continue to run. execution_start_to_close_timeout (string) – The total duration for this workflow execution. This overrides the defaultExecutionStartToCloseTimeout specified when registering the workflow type. input (string) – The input for the workflow execution. This is a free form string which should be meaningful to the workflow you are starting. This input is made available to the new workflow execution in the WorkflowExecutionStarted history event.

    task_start_to_close_timeout: Specifies the maximum duration of
      decision tasks for this workflow execution. This parameter overrides the defaultTaskStartToCloseTimout specified when registering the workflow type using register_workflow_type.

    Raises : | UnknownResourceFault, TypeDeprecatedFault, SWFWorkflowExecutionAlreadyStartedError, SWFLimitExceededError, SWFOperationNotPermittedError, DefaultUndefinedFault

`boto.swf.layer2.` `set_default_credentials`(aws_access_key_id, aws_secret_access_key)

  Set default credentials.

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.21.1 »